# Request


## Control

```{eval-rst}

.. automodule:: torii_usb.usb.request.control
	:members:

```

## Interface

```{eval-rst}

.. automodule:: torii_usb.usb.request.interface
	:members:

```

## Standard

```{eval-rst}

.. automodule:: torii_usb.usb.request.standard
	:members:

```

## Windows

```{eval-rst}

.. automodule:: torii_usb.usb.request.windows
	:members:

.. automodule:: torii_usb.usb.request.windows.descriptorSet
	:members:

```
